@@ -1,6 +1,11 @@
-use std::{borrow::Cow, convert::TryInto, path::Path};
+use std::{
+    borrow::Cow,
+    convert::TryInto,
+    path::{Path, PathBuf},
+};
 
-use bstr::{BStr, BString, ByteSlice, ByteVec};
+use git_object::bstr::{BStr, BString, ByteSlice, ByteVec};
+use os_str_bytes::OsStrBytes;
 
 use crate::{Namespace, PartialNameRef};
 
@@ -17,6 +22,15 @@ impl Namespace {
     pub fn to_path(&self) -> Cow<'_, Path> {
         self.0.to_path().expect("UTF-8 conversion succeeds").into()
     }
+    /// Append the given `prefix` to this namespace so it becomes usable for prefixed iteration.
+    pub fn into_namespaced_prefix(mut self, prefix: impl AsRef<Path>) -> PathBuf {
+        self.0.push_str(prefix.as_ref().to_raw_bytes());
+        #[cfg(windows)]
+        let path = self.0.replace(b"/", b"\\").into_path_buf();
+        #[cfg(not(windows))]
+        let path = self.0.replace(b"\\", b"/").into_path_buf();
+        path.expect("UTF-8 conversion succeeds")
+    }
 }
 
 /// Given a `namespace` 'foo we output 'refs/namespaces/foo', and given 'foo/bar' we output 'refs/namespaces/foo/refs/namespaces/bar'.
